from pathlib import Path
from typing import Iterator

from casedockets.simple_matcher import updated_cat_idx
from sqlite_utils.db import Table
from utils_api.files import OLD_PATH, SC_PATH, load_yaml_from_path

from .config import DB, DECISIONS, JUSTICES, VOTING_LINES
from .organizer import (
    extract_fallo,
    process_fields,
    remove_other_keys,
    updated_ponente_id,
)
from .raw_sql import duplicate_elements_of_dockets, duplicate_phil_reports


def init_db():
    for i in [JUSTICES, DECISIONS, VOTING_LINES]:
        if not isinstance(i, Table):
            raise Exception("Missing table.")
    DB.create_view("duplicate_phils", duplicate_phil_reports, ignore=True)
    DB.create_view("duplicate_dockets", duplicate_elements_of_dockets, ignore=True)


def get_unique_decisions():
    dup_phil_pks = [row["pk"] for row in DB["duplicate_phils"].rows]
    dup_docket_pks = [row["pk"] for row in DB["duplicate_dockets"].rows]
    dups = dup_phil_pks + dup_docket_pks
    for row in DECISIONS.rows:
        if row["pk"] not in dups:
            yield row


def add_old():
    DECISIONS.insert_all(get_meta(OLD_PATH), ignore=True, defaults={"per_curiam": 0})


def add_sc():
    DECISIONS.insert_all(get_meta(SC_PATH), ignore=True, defaults={"per_curiam": 0})


def get_meta(folder: Path) -> Iterator[dict]:
    for detail in folder.glob("**/details.yaml"):
        res = remove_other_keys(load_yaml_from_path(detail))
        res |= updated_cat_idx(res) | process_fields(res, detail, folder)
        yield res | updated_ponente_id(res) | extract_fallo(detail.parent)
